/***************************************************************************
                          fleet.cpp  -  description
                             -------------------
    begin                : Tue Jan 22 2002
    copyright            : (C) 2002 by Michael Andreen
    email                : whale@linux.nu
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "fleet.h"

#include <iostream>
using namespace std;

//Static variables
map<string, vector<int> > Fleet::s_Races;
map<string, UnitType > Fleet::s_Units;

Fleet::Fleet()
{
	m_iETA = 0;
	m_sRace = "Generic";
}
Fleet::~Fleet(){
}

//////////////////////////////////////////////////////////////////////////
//
void Fleet::setName(string sName)
{
	m_sName = sName;
}

//////////////////////////////////////////////////////////////////////////
//
string Fleet::Name() const
{
	return m_sName;
}

//////////////////////////////////////////////////////////////////////////
//
/** This function first sets the race, then it iterates through the the 
 * s_Races and checks if it finds the race it returns true, if it reaches
 * the end without finding it it returns false.
 */
bool Fleet::setRace(string sRace)
{
	m_sRace = sRace;
	for (map<string, vector<int> >::iterator i = s_Races.begin(); i != s_Races.end(); i++)
	{
		if (m_sRace == (*i).first)
			return true;
	}
	return false;
}

//////////////////////////////////////////////////////////////////////////
//
string Fleet::Race() const
{
	return m_sRace;
}

//////////////////////////////////////////////////////////////////////////
//
/** This function iterates through m_Fleet and adds all numbers together to
 * produce a total.
 */
int Fleet::NumberOfShips() const
{
	int total = 0;

	for (map<string, vector<int> >::const_iterator i = m_Fleet.begin(); i != m_Fleet.end(); ++i)
	{
		total += i->second[0];
	}

	return total;
}

//////////////////////////////////////////////////////////////////////////
//
void Fleet::setETA(int eta)
{
	m_iETA = eta;
}

//////////////////////////////////////////////////////////////////////////
//
int  Fleet::ETA() const
{
	return m_iETA;
}

//////////////////////////////////////////////////////////////////////////
//
void Fleet::setRaces(map<string, vector<int> >& races)
{
	s_Races = races;
}

//////////////////////////////////////////////////////////////////////////
//
void Fleet::setUnits(map<string, UnitType>& units)
{
	s_Units = units;

	for (map<string, UnitType >::iterator i = s_Units.begin(); i != s_Units.end(); i++)
	{
		cerr << s_Units[(*i).first].Name() << "\t\t"
			<< s_Units[(*i).first].Race() <<"\t"
			<< s_Units[(*i).first].Class() << "\t"
			<< s_Units[(*i).first].Target(0) << "\t"
			<< s_Units[(*i).first].Target(1) << "\t"
			<< s_Units[(*i).first].Target(2) << "\t"
			<< s_Units[(*i).first].Initiative() << "\t"
			<< s_Units[(*i).first].Agility() << "\t"
			<< s_Units[(*i).first].WeaponSpeed() << "\t"
			<< s_Units[(*i).first].Guns() << "\t"
			<< s_Units[(*i).first].Power() << "\t"
			<< s_Units[(*i).first].Armor() << "\t"
			<< s_Units[(*i).first].EMP() << "\t"
			<< s_Units[(*i).first].TotRes() << "\t"
			<< s_Units[(*i).first].Fuel() << "\t"
			<< s_Units[(*i).first].ETA() << "\t"
			<< s_Units[(*i).first].Type() << endl;
	}
}

//////////////////////////////////////////////////////////////////////////
//
const map<string, vector<int> >& Fleet::Races()
{
	return s_Races;
}

//////////////////////////////////////////////////////////////////////////
//
const map<string, UnitType>& Fleet::Units()
{
	return s_Units;
}



